Get STICS executable version number, or string, or hash

get_version_number(exe_path, numeric = TRUE)

Arguments

exe_path

executable file path

numeric

Logical, TRUE (default) to return a numeric version as a semver class vector, or FALSE to return a character string with the version

Value

a semver class vector if numeric = TRUE (default), or a character string if numeric = FALSE, with an attribute "date" if the version date is provided in the system command output. Or a hash string if the system command output contains a hash. Or a label string if neither a version number nor a hash is found.

Examples

if (FALSE) { # \dontrun{
get_version_number("path/to/stics_exe")
get_version_number("path/to/stics_exe", numeric = FALSE)
} # }