R/stics_exe_utilities.R
get_version_number.RdGet STICS executable version number, or string, or hash
get_version_number(exe_path, numeric = TRUE)a semver class vector if numeric = TRUE (default),
or a character string if numeric = FALSE, with an attribute "date" if
the version date is provided in the system command output.
Or a hash string if the system command output contains a hash.
Or a label string if neither a version number nor a hash is found.
if (FALSE) { # \dontrun{
get_version_number("path/to/stics_exe")
get_version_number("path/to/stics_exe", numeric = FALSE)
} # }